# Rustic AI Core

Rustic AI Core provides the foundational interfaces and components necessary for building human-centered, multi-agent
applications. 

## Installing

```shell
pip install rusticai-core
```

## Building from Source

```shell
poetry install --with dev
poetry build
```
